Struct Parse

struct Parse<'a> { ... }

The return type of parse().

Implementations

impl<'a> Parse<'a>

fn into_owned(self: Self) -> ParseIntoOwned<'a>

Return a new iterator that yields pairs of String instead of pairs of Cow<str>.

impl<'a> Clone for Parse<'a>

fn clone(self: &Self) -> Parse<'a>

impl<'a> Copy for Parse<'a>

impl<'a> Freeze for Parse<'a>

impl<'a> Iterator for Parse<'a>

fn next(self: &mut Self) -> Option<<Self as >::Item>

impl<'a> RefUnwindSafe for Parse<'a>

impl<'a> Send for Parse<'a>

impl<'a> Sync for Parse<'a>

impl<'a> Unpin for Parse<'a>

impl<'a> UnsafeUnpin for Parse<'a>

impl<'a> UnwindSafe for Parse<'a>

impl<I> IntoIterator for Parse<'a>

fn into_iter(self: Self) -> I

impl<T> Any for Parse<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Parse<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Parse<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Parse<'a>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Parse<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Parse<'a>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Parse<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Parse<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Parse<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>